@@ -9,7 +9,7 @@ __license__ = "GPL"
 __version__ = "$Revision: 49482 $"
 
 from zope.app.zapi import getUtility
-from objectqueue.interfaces import IObjectQueue
+from ng.app.objectqueue.interfaces import IObjectQueue
 from zope.component import ComponentLookupError
 from interfaces import IRSS
 
